# Pleroma: A lightweight social networking server
# Copyright © 2017-2022 Pleroma Authors <https://pleroma.social/>
# SPDX-License-Identifier: AGPL-3.0-only


defmodule Pleroma.Web.ActivityPub.MRF.DontBoostGuppeReplies do
  alias Pleroma.User
  @moduledoc "Ignores boosts that have a reply to a guppe account, written by foxes@myfriendsare.gay"
  @behaviour Pleroma.Web.ActivityPub.MRF.Policy

  alias Pleroma.Object

  require Logger

  def history_awareness, do: :auto

  def filter(
      %{
        "type" => "Announce",
        "actor" => actor,
        "object" => object
      } = message
    ) do

    Logger.debug("GUPPE ACTOR #{inspect(actor)}")
    if actor =~ "https://a.gup.pe/u/" do
      child = Object.get_by_ap_id(object).data
      Logger.debug("GUPPE OBJECT #{inspect(child)}")
        if child["inReplyTo"] != nil do
          Logger.debug("GUPPE REJECT #{object}")
        {:reject, message}
        else
          Logger.debug("GUPPE ALLOW #{object}")
        {:ok, message}
        end
    else
      {:ok, message}
    end
  end



  @impl true
  def filter(message), do: {:ok, message}

  @impl true
  def describe, do: {:ok, %{}}
end
